@@ -154,6 +154,10 @@ void             gtk_icon_view_unselect_path      (GtkIconView            *icon_
 						   GtkTreePath            *path);
 gboolean         gtk_icon_view_path_is_selected   (GtkIconView            *icon_view,
 						   GtkTreePath            *path);
+gint             gtk_icon_view_get_item_row       (GtkIconView            *icon_view,
+                                                   GtkTreePath            *path);
+gint             gtk_icon_view_get_item_column    (GtkIconView            *icon_view,
+                                                   GtkTreePath            *path);
 GList           *gtk_icon_view_get_selected_items (GtkIconView            *icon_view);
 void             gtk_icon_view_select_all         (GtkIconView            *icon_view);
 void             gtk_icon_view_unselect_all       (GtkIconView            *icon_view);
