@@ -21,6 +21,8 @@
 /* need to get the prototypes of all get_type functions */
 #define GTK_ENABLE_BROKEN
 #undef GTK_DISABLE_DEPRECATED
+/* Need to get GDK_WINDOW_OBJECT */
+#undef GDK_DISABLE_DEPRECATED
 
 #include "config.h"
 
@@ -32,7 +34,12 @@
 #include <math.h>
 
 
-/* --- test utilities --- */
+/**
+ * SECTION:gtktesting
+ * @Short_description: Utilities for testing GTK+ applications
+ * @Title: Testing
+ */
+
 /**
  * gtk_test_init:
  * @argcp: Address of the <parameter>argc</parameter> parameter of the
@@ -482,7 +489,7 @@ gtk_test_text_get (GtkWidget *widget)
 /**
  * gtk_test_create_widget
  * @widget_type: a valid widget type.
- * @first_property_name: Name of first property to set or %NULL
+ * @first_property_name: (allow-none): Name of first property to set or %NULL
  * @Varargs: value to set the first property to, followed by more
  *    name-value pairs, terminated by %NULL
  *
